==> qt6-declarative_6.2.4+dfsg.orig.tar.xz: qtdeclarative-everywhere-src-6.2.4/src/labs/platform/qquicklabsplatformstandardpaths_p.h <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Labs Platform module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QQUICKLABSPLATFORMSTANDARDPATHS_P_H
#define QQUICKLABSPLATFORMSTANDARDPATHS_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <QtCore/qobject.h>
#include <QtCore/qstandardpaths.h>
#include <QtCore/qurl.h>
#include <QtQml/qqml.h>

QT_BEGIN_NAMESPACE

class QQmlEngine;
class QJSEngine;

class QQuickLabsPlatformStandardPaths : public QObject
{
    Q_OBJECT
    Q_ENUMS(QStandardPaths::StandardLocation QStandardPaths::LocateOptions)

public:
    explicit QQuickLabsPlatformStandardPaths(QObject *parent = nullptr);

    static QObject *create(QQmlEngine *engine, QJSEngine *scriptEngine);

    Q_INVOKABLE static QString displayName(QStandardPaths::StandardLocation type);
    Q_INVOKABLE static QUrl findExecutable(const QString &executableName, const QStringList &paths = QStringList());
    Q_INVOKABLE static QUrl locate(QStandardPaths::StandardLocation type, const QString &fileName, QStandardPaths::LocateOptions options = QStandardPaths::LocateFile);
    Q_INVOKABLE static QList<QUrl> locateAll(QStandardPaths::StandardLocation type, const QString &fileName, QStandardPaths::LocateOptions options = QStandardPaths::LocateFile);
    Q_INVOKABLE static void setTestModeEnabled(bool testMode);
    Q_INVOKABLE static QList<QUrl> standardLocations(QStandardPaths::StandardLocation type);
    Q_INVOKABLE static QUrl writableLocation(QStandardPaths::StandardLocation type);

private:
    Q_DISABLE_COPY(QQuickLabsPlatformStandardPaths)
};

QT_END_NAMESPACE

QML_DECLARE_TYPE(QQuickLabsPlatformStandardPaths)
Q_DECLARE_METATYPE(QStandardPaths::StandardLocation)
Q_DECLARE_METATYPE(QStandardPaths::LocateOptions)

#endif // QQUICKLABSPLATFORMSTANDARDPATHS_P_H

==> qt6-declarative_6.4.2+dfsg.orig.tar.xz: qtdeclarative-everywhere-src-6.4.2/src/labs/platform/qquicklabsplatformstandardpaths_p.h <==
// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QQUICKLABSPLATFORMSTANDARDPATHS_P_H
#define QQUICKLABSPLATFORMSTANDARDPATHS_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <QtCore/qobject.h>
#include <QtCore/qstandardpaths.h>
#include <QtCore/qurl.h>
#include <QtQml/qqml.h>
#include <QtCore/private/qglobal_p.h>

#if QT_DEPRECATED_SINCE(6, 4)

QT_BEGIN_NAMESPACE

class QQmlEngine;
class QJSEngine;

class QQuickLabsPlatformStandardPaths : public QObject
{
    Q_OBJECT
    QML_SINGLETON
    QML_NAMED_ELEMENT(StandardPaths)
    QML_EXTENDED_NAMESPACE(QStandardPaths)

public:
    explicit QQuickLabsPlatformStandardPaths(QObject *parent = nullptr);

    static QObject *create(QQmlEngine *engine, QJSEngine *scriptEngine);

    Q_INVOKABLE static QString displayName(QStandardPaths::StandardLocation type);
    Q_INVOKABLE static QUrl findExecutable(const QString &executableName, const QStringList &paths = QStringList());
    Q_INVOKABLE static QUrl locate(QStandardPaths::StandardLocation type, const QString &fileName, QStandardPaths::LocateOptions options = QStandardPaths::LocateFile);
    Q_INVOKABLE static QList<QUrl> locateAll(QStandardPaths::StandardLocation type, const QString &fileName, QStandardPaths::LocateOptions options = QStandardPaths::LocateFile);
    Q_INVOKABLE static void setTestModeEnabled(bool testMode);
    Q_INVOKABLE static QList<QUrl> standardLocations(QStandardPaths::StandardLocation type);
    Q_INVOKABLE static QUrl writableLocation(QStandardPaths::StandardLocation type);

private:
    Q_DISABLE_COPY(QQuickLabsPlatformStandardPaths)
};

QT_END_NAMESPACE

QML_DECLARE_TYPE(QQuickLabsPlatformStandardPaths)
Q_DECLARE_METATYPE(QStandardPaths::StandardLocation)
Q_DECLARE_METATYPE(QStandardPaths::LocateOptions)

#endif // QT_DEPRECATED_SINCE(6, 4)

#endif // QQUICKLABSPLATFORMSTANDARDPATHS_P_H
